Converts timestamps from radar time zone to an user-defined time zone
Source:R/convertTimeZone.R
convertTimeZone.RdConverts timestamps from radar time zone to an user-defined time zone
Value
a data frame identical to data, any columns declared in colNames
will have their name changed with a suffix (_originTZ or _targetTZ) added.
See also
Other manipulation functions:
addDayNightInfoPerEcho(),
computeDensity(),
computeMTR(),
createVPTS(),
filterSpeedFeature37(),
mergeVisibilityAndManualBlindTimes(),
reclassToBats(),
twilight()
Examples
# \donttest{
# Load example data
# ===========================================================================
dbData = readRDS(system.file("extdata",
"CH_Sempach_2024_SEP24_25_DataExtract.rds",
package = "birdscanR"
))
# Add day/night info to echo data
# ===========================================================================
echoData = convertTimeZone(
data = dbData$echoData,
colNames = c("time_stamp"),
originTZ = "Etc/GMT0",
targetTZ = "Etc/GMT-2"
)
#> Warning: no data to convert to time zone (function: convertTimeZone)
# }